import { isRecord } from './record';


// Description of an individual item in the To-Do list
export type Item = {
  name: string;
  completed: boolean;
};


/**
 * Parses unknown data into an array of Items. Will log an error and return
 * undefined if it is not an array of Items.
 * @param val unknown data to parse into an array of Items
 * @return Item[] if val is an array of Items and undefined otherwise
 */
export const parseItems = (val: unknown): undefined | Item[] => {
  if (!Array.isArray(val)) {
    console.error("not an array", val);
    return undefined;
  }

  const items: Item[] = [];
  for (const item of val) {
    if (!isRecord(item)) {
      console.error("item is not a record", val);
      return undefined;
    } else if (typeof item.name !== 'string') {
      console.error("item.name is missing or invalid", item.name);
      return undefined;
    } else if (typeof item.completed !== 'boolean') {
      console.error("item.completed is missing or invalid", item.completed);
      return undefined;
    } else {
      items.push({name: item.name, completed: item.completed});
    }
  }
  return items;
};
